pub struct RefreshingLoginCredentials<S: TokenStorage> { /* private fields */ }Expand description
Login credentials backed by a token storage and using OAuth refresh tokens, allowing use of OAuth tokens that expire.
These can also be cloned before being passed to a Client so you can use them in other places,
such as API calls.
Implementations
Sourceimpl<S: TokenStorage> RefreshingLoginCredentials<S>
impl<S: TokenStorage> RefreshingLoginCredentials<S>
Sourcepub fn init(
client_id: String,
client_secret: String,
token_storage: S,
) -> RefreshingLoginCredentials<S>
pub fn init( client_id: String, client_secret: String, token_storage: S, ) -> RefreshingLoginCredentials<S>
Create new login credentials with a backing token storage. The username belonging to the stored token is automatically fetched using the Twitch API when using this constructor.
Sourcepub fn init_with_username(
user_login: Option<String>,
client_id: String,
client_secret: String,
token_storage: S,
) -> RefreshingLoginCredentials<S>
pub fn init_with_username( user_login: Option<String>, client_id: String, client_secret: String, token_storage: S, ) -> RefreshingLoginCredentials<S>
Create new login credentials with a backing token storage and a predefined username.
If the username is predefined (pass Some("the_username") as user_login),
no API call will be made to the Twitch API to determine the username belonging to the token.
If the passed user_login is None, this constructor is functionally equivalent to RefreshingLoginCredentials::init.