pub struct StaticLoginCredentials {
pub credentials: CredentialsPair,
}Expand description
Simple LoginCredentials implementation that always returns the same CredentialsPair
and never fails.
Fields
credentials: CredentialsPairThe credentials that are always returned.
Implementations
Sourceimpl StaticLoginCredentials
impl StaticLoginCredentials
Sourcepub fn new(login: String, token: Option<String>) -> StaticLoginCredentials
pub fn new(login: String, token: Option<String>) -> StaticLoginCredentials
Create new static login credentials from the given Twitch login name and OAuth access token.
The token should be without the oauth: prefix.
Sourcepub fn anonymous() -> StaticLoginCredentials
pub fn anonymous() -> StaticLoginCredentials
Creates login credentials for logging into chat as an anonymous user.