pub enum ServerMessageParseError {
MismatchedCommand(Box<IRCMessage>),
MissingTag(Box<IRCMessage>, &'static str),
MissingTagValue(Box<IRCMessage>, &'static str),
MalformedTagValue(Box<IRCMessage>, &'static str, String),
MissingParameter(Box<IRCMessage>, usize),
MalformedChannel(Box<IRCMessage>),
MalformedParameter(Box<IRCMessage>, usize),
MissingPrefix(Box<IRCMessage>),
MissingNickname(Box<IRCMessage>),
}Expand description
Errors encountered while trying to parse an IRC message as a more specialized “server message”, based on its IRC command.
Variants
MismatchedCommand(Box<IRCMessage>)
That command’s data is not parsed by this implementation
This type of error is only returned if you use try_from directly on a special
server message implementation, instead of the general ServerMessage::try_from
which covers all implementations and does not emit this type of error.
MissingTag(Box<IRCMessage>, &'static str)
No tag present under key key
MissingTagValue(Box<IRCMessage>, &'static str)
No tag value present under key key
MalformedTagValue(Box<IRCMessage>, &'static str, String)
Malformed tag value for tag key, value was value
MissingParameter(Box<IRCMessage>, usize)
No parameter found at index n
MalformedChannel(Box<IRCMessage>)
Malformed channel parameter (# must be present + something after it)
MalformedParameter(Box<IRCMessage>, usize)
Malformed parameter at index n
MissingPrefix(Box<IRCMessage>)
Missing prefix altogether
MissingNickname(Box<IRCMessage>)
No nickname found in prefix