pub struct ReplyParent {
pub message_id: String,
pub reply_parent_user: TwitchUserBasics,
pub message_text: String,
}Expand description
If a message is sent in reply to another one, Twitch provides some basic information about the message that was replied to. It is optional, as not every message will be in reply to another message.
Fields
message_id: StringMessage UUID that this message is replying to.
reply_parent_user: TwitchUserBasicsUser that sent the message that is replying to.
message_text: StringThe text of the message that this message is replying to.